export default {".table":{"@layer daisyui.l1.l2.l3":{"font-size":"0.875rem","position":"relative","width":"100%","border-collapse":"separate","--tw-border-spacing-x":"calc(0.25rem * 0)","--tw-border-spacing-y":"calc(0.25rem * 0)","border-spacing":"var(--tw-border-spacing-x) var(--tw-border-spacing-y)","border-radius":"var(--radius-box)","text-align":"left","&:where(:dir(rtl), [dir=\"rtl\"], [dir=\"rtl\"] *)":{"text-align":"right"},"tr.row-hover":{"&, &:nth-child(even)":{"&:hover":{"@media (hover: hover)":{"background-color":"var(--color-base-200)"}}}},":where(th, td)":{"padding-inline":"calc(0.25rem * 4)","padding-block":"calc(0.25rem * 3)","vertical-align":"middle"},":where(thead, tfoot)":{"white-space":"nowrap","color":"color-mix(in oklab, var(--color-base-content) 60%, transparent)","font-size":"0.875rem","font-weight":600},":where(tfoot tr:first-child :is(td, th))":{"border-top":"var(--border) solid color-mix(in oklch, var(--color-base-content) 5%, #0000)"},":where(.table-pin-rows thead tr)":{"position":"sticky","top":"calc(0.25rem * 0)","z-index":1,"background-color":"var(--color-base-100)"},":where(.table-pin-rows tfoot tr)":{"position":"sticky","bottom":"calc(0.25rem * 0)","z-index":1,"background-color":"var(--color-base-100)"},":where(.table-pin-cols tr th)":{"position":"sticky","right":"calc(0.25rem * 0)","left":"calc(0.25rem * 0)","background-color":"var(--color-base-100)"},":where(thead tr :is(td, th), tbody tr:not(:last-child) :is(td, th))":{"border-bottom":"var(--border) solid color-mix(in oklch, var(--color-base-content) 5%, #0000)"}}},".table-zebra":{"@layer daisyui.l1.l2":{"tbody":{"tr":{"&:where(:nth-child(even))":{"background-color":"var(--color-base-200)",":where(.table-pin-cols tr th)":{"background-color":"var(--color-base-200)"}},"&.row-hover":{"&, &:where(:nth-child(even))":{"&:hover":{"@media (hover: hover)":{"background-color":"var(--color-base-300)"}}}}}}}},".table-xs":{"@layer daisyui.l1.l2":{":not(thead, tfoot) tr":{"font-size":"0.6875rem"},":where(th, td)":{"padding-inline":"calc(0.25rem * 2)","padding-block":"calc(0.25rem * 1)"}}},".table-sm":{"@layer daisyui.l1.l2":{":not(thead, tfoot) tr":{"font-size":"0.75rem"},":where(th, td)":{"padding-inline":"calc(0.25rem * 3)","padding-block":"calc(0.25rem * 2)"}}},".table-md":{"@layer daisyui.l1.l2":{":not(thead, tfoot) tr":{"font-size":"0.875rem"},":where(th, td)":{"padding-inline":"calc(0.25rem * 4)","padding-block":"calc(0.25rem * 3)"}}},".table-lg":{"@layer daisyui.l1.l2":{":not(thead, tfoot) tr":{"font-size":"1.125rem"},":where(th, td)":{"padding-inline":"calc(0.25rem * 5)","padding-block":"calc(0.25rem * 4)"}}},".table-xl":{"@layer daisyui.l1.l2":{":not(thead, tfoot) tr":{"font-size":"1.375rem"},":where(th, td)":{"padding-inline":"calc(0.25rem * 6)","padding-block":"calc(0.25rem * 5)"}}}};