export default {".card":{"@layer daisyui.l1.l2.l3":{"position":"relative","display":"flex","flex-direction":"column","border-radius":"var(--radius-box)","outline-width":"2px","transition":"outline 0.2s ease-in-out","outline":"0 solid #0000","outline-offset":"2px","&:focus":{"--tw-outline-style":"none","outline-style":"none","@media (forced-colors: active)":{"outline":"2px solid transparent","outline-offset":"2px"}},"&:focus-visible":{"outline-color":"currentColor"},":where(figure:first-child)":{"overflow":"hidden","border-start-start-radius":"inherit","border-start-end-radius":"inherit","border-end-start-radius":"unset","border-end-end-radius":"unset"},":where(figure:last-child)":{"overflow":"hidden","border-start-start-radius":"unset","border-start-end-radius":"unset","border-end-start-radius":"inherit","border-end-end-radius":"inherit"},"figure":{"display":"flex","align-items":"center","justify-content":"center"},"&:has(> input:is(input[type=\"checkbox\"], input[type=\"radio\"]))":{"cursor":"pointer","user-select":"none"},"&:has(> :checked)":{"outline":"2px solid currentColor"}}},".card-border":{"@layer daisyui.l1.l2":{"border":"var(--border) solid var(--color-base-200)"}},".card-dash":{"@layer daisyui.l1.l2":{"border":"var(--border) dashed var(--color-base-200)"}},".image-full":{"@layer daisyui.l1.l2":{"display":"grid","> *":{"grid-column-start":"1","grid-row-start":"1"},"> .card-body":{"position":"relative","color":"var(--color-neutral-content)"},":where(figure)":{"overflow":"hidden","border-radius":"inherit"},"> figure img":{"height":"100%","object-fit":"cover","filter":"brightness(28%)"}}},".card-title":{"@layer daisyui.l1.l2.l3":{"display":"flex","align-items":"center","gap":"calc(0.25rem * 2)","font-size":"var(--cardtitle-fs, 1.125rem)","font-weight":600}},".card-body":{"@layer daisyui.l1.l2.l3":{"display":"flex","flex":"auto","flex-direction":"column","gap":"calc(0.25rem * 2)","padding":"var(--card-p, 1.5rem)","font-size":"var(--card-fs, 0.875rem)",":where(p)":{"flex-grow":1}}},".card-actions":{"@layer daisyui.l1.l2.l3":{"display":"flex","flex-wrap":"wrap","align-items":"flex-start","gap":"calc(0.25rem * 2)"}},".card-xs":{"@layer daisyui.l1.l2":{".card-body":{"--card-p":"0.5rem","--card-fs":"0.6875rem"},".card-title":{"--cardtitle-fs":"0.875rem"}}},".card-sm":{"@layer daisyui.l1.l2":{".card-body":{"--card-p":"1rem","--card-fs":"0.75rem"},".card-title":{"--cardtitle-fs":"1rem"}}},".card-md":{"@layer daisyui.l1.l2":{".card-body":{"--card-p":"1.5rem","--card-fs":"0.875rem"},".card-title":{"--cardtitle-fs":"1.125rem"}}},".card-lg":{"@layer daisyui.l1.l2":{".card-body":{"--card-p":"2rem","--card-fs":"1rem"},".card-title":{"--cardtitle-fs":"1.25rem"}}},".card-xl":{"@layer daisyui.l1.l2":{".card-body":{"--card-p":"2.5rem","--card-fs":"1.125rem"},".card-title":{"--cardtitle-fs":"1.375rem"}}},".card-side":{"@layer daisyui.l1.l2":{"align-items":"stretch","flex-direction":"row",":where(figure:first-child)":{"overflow":"hidden","border-start-start-radius":"inherit","border-start-end-radius":"unset","border-end-start-radius":"inherit","border-end-end-radius":"unset"},":where(figure:last-child)":{"overflow":"hidden","border-start-start-radius":"unset","border-start-end-radius":"inherit","border-end-start-radius":"unset","border-end-end-radius":"inherit"},"figure > *":{"max-width":"unset"},":where(figure > *)":{"width":"100%","height":"100%","object-fit":"cover"}}}};