export default {".mockup-code":{"@layer daisyui.l1.l2.l3":{"position":"relative","overflow":"hidden","overflow-x":"auto","border-radius":"var(--radius-box)","background-color":"var(--color-neutral)","padding-block":"calc(0.25rem * 5)","color":"var(--color-neutral-content)","font-size":"0.875rem","direction":"ltr","&:before":{"content":"\"\"","margin-bottom":"calc(0.25rem * 4)","display":"block","height":"calc(0.25rem * 3)","width":"calc(0.25rem * 3)","border-radius":"calc(infinity * 1px)","opacity":"30%","box-shadow":"1.4em 0, 2.8em 0, 4.2em 0"},"pre":{"padding-right":"calc(0.25rem * 5)","&:before":{"content":"\"\"","margin-right":"2ch"},"&[data-prefix]":{"&:before":{"--tw-content":"attr(data-prefix)","content":"var(--tw-content)","display":"inline-block","width":"calc(0.25rem * 8)","text-align":"right","opacity":"50%"}}}}},".mockup-window":{"@layer daisyui.l1.l2.l3":{"position":"relative","display":"flex","flex-direction":"column","overflow":"hidden","overflow-x":"auto","border-radius":"var(--radius-box)","padding-top":"calc(0.25rem * 5)","&:before":{"content":"\"\"","margin-bottom":"calc(0.25rem * 4)","display":"block","aspect-ratio":"1 / 1","height":"calc(0.25rem * 3)","flex-shrink":0,"align-self":"flex-start","border-radius":"calc(infinity * 1px)","opacity":"30%","box-shadow":"1.4em 0, 2.8em 0, 4.2em 0"},"[dir=\"rtl\"] &:before":{"align-self":"flex-end"},"pre[data-prefix]":{"&:before":{"--tw-content":"attr(data-prefix)","content":"var(--tw-content)","display":"inline-block","text-align":"right"}}}},".mockup-browser":{"@layer daisyui.l1.l2.l3":{"position":"relative","overflow":"hidden","overflow-x":"auto","border-radius":"var(--radius-box)","pre[data-prefix]":{"&:before":{"--tw-content":"attr(data-prefix)","content":"var(--tw-content)","display":"inline-block","text-align":"right"}},".mockup-browser-toolbar":{"margin-block":"calc(0.25rem * 3)","display":"inline-flex","width":"100%","align-items":"center","padding-right":"1.4em","&:where(:dir(rtl), [dir=\"rtl\"], [dir=\"rtl\"] *)":{"flex-direction":"row-reverse"},"&:before":{"content":"\"\"","margin-right":"4.8rem","display":"inline-block","aspect-ratio":"1 / 1","height":"calc(0.25rem * 3)","border-radius":"calc(infinity * 1px)","opacity":"30%","box-shadow":"1.4em 0, 2.8em 0, 4.2em 0"},".input":{"margin-inline":"auto","display":"flex","height":"100%","align-items":"center","gap":"calc(0.25rem * 2)","overflow":"hidden","background-color":"var(--color-base-200)","text-overflow":"ellipsis","white-space":"nowrap","font-size":"0.75rem","direction":"ltr","&:before":{"content":"\"\"","width":"calc(0.25rem * 4)","height":"calc(0.25rem * 4)","opacity":"50%","background-color":"currentColor","mask":"url(\"data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'%3E%3Cpath fill-rule='evenodd' d='M9.965 11.026a5 5 0 1 1 1.06-1.06l2.755 2.754a.75.75 0 1 1-1.06 1.06l-2.755-2.754ZM10.5 7a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0Z' clip-rule='evenodd' /%3E%3C/svg%3E\") no-repeat center","mask-size":"contain"}}}}},".mockup-phone":{"@layer daisyui.l1.l2.l3":{"display":"inline-grid","justify-items":"center","border":"5px solid #6b6b6b","border-radius":"65px","background-color":"#000","padding":"6px","overflow":"hidden","width":"100%","max-width":"462px","aspect-ratio":"462 / 978","@supports (corner-shape: superellipse(1.45))":{"border-radius":"90px","corner-shape":"superellipse(1.45)"}}},".mockup-phone-camera":{"@layer daisyui.l1.l2.l3":{"grid-column":"1/1","grid-row":"1/1","background":"#000","height":"3.7%","width":"28%","border-radius":"17px","z-index":1,"margin-top":"3%"}},".mockup-phone-display":{"@layer daisyui.l1.l2.l3":{"border-radius":"54px","grid-column":"1/1","grid-row":"1/1","overflow":"hidden","width":"100%","height":"100%","@supports (corner-shape: superellipse(1.87))":{"border-radius":"101px","corner-shape":"superellipse(1.87)"},"& > img":{"width":"100%","height":"100%","object-fit":"cover"}}}};