export default {".diff":{"@layer daisyui.l1.l2.l3":{"position":"relative","display":"grid","width":"100%","overflow":"hidden","webkit-user-select":"none","user-select":"none","grid-template-rows":"1fr 1.8rem 1fr","direction":"ltr","container-type":"inline-size","grid-template-columns":"auto 1fr","&:focus-visible, &:has(.diff-item-1:focus-visible)":{"outline-style":"var(--tw-outline-style)","outline-width":"2px","outline-offset":"1px","outline-color":"var(--color-base-content)"},"&:focus-visible":{"outline-style":"var(--tw-outline-style)","outline-width":"2px","outline-offset":"1px","outline-color":"var(--color-base-content)",".diff-resizer":{"min-width":"95cqi","max-width":"95cqi"}},"&:has(.diff-item-1:focus-visible)":{"outline-style":"var(--tw-outline-style)","outline-width":"2px","outline-offset":"1px",".diff-resizer":{"min-width":"5cqi","max-width":"5cqi"}},"@supports (-webkit-overflow-scrolling: touch) and (overflow: -webkit-paged-x)":{"&:focus":{".diff-resizer":{"min-width":"5cqi","max-width":"5cqi"}},"&:has(.diff-item-1:focus)":{".diff-resizer":{"min-width":"95cqi","max-width":"95cqi"}}}}},".diff-resizer":{"@layer daisyui.l1.l2.l3":{"position":"relative","isolation":"isolate","z-index":2,"grid-column-start":"1","grid-row-start":"2","height":"calc(0.25rem * 3)","width":"50cqi","max-width":"calc(100cqi - 1rem)","min-width":"1rem","resize":"horizontal","overflow":"hidden","opacity":"0%","transform":"scaleY(5) translate(0.32rem, 50%)","cursor":"ew-resize","transform-origin":"100% 100%","clip-path":"inset(calc(100% - 0.75rem) 0 0 calc(100% - 0.75rem))","transition":"min-width 0.3s ease-out, max-width 0.3s ease-out"}},".diff-item-2":{"@layer daisyui.l1.l2.l3":{"position":"relative","grid-column-start":"1","grid-row":"span 3 / span 3","grid-row-start":"1","&:after":{"pointer-events":"none","position":"absolute","top":"calc(1/2 * 100%)","right":"1px","bottom":"calc(0.25rem * 0)","z-index":2,"border-radius":"calc(infinity * 1px)","background-color":"color-mix(in oklab, var(--color-base-100) 98%, transparent)","width":"1.2rem","height":"1.8rem","border":["2px solid var(--color-base-100)","0.5px solid #0000001f"],"content":"\"\"","outline":"1px solid color-mix(in oklab, var(--color-base-content) 10%, #0000)","outline-offset":"-3px","translate":"50% -50%"},"> *":{"pointer-events":"none","position":"absolute","top":"calc(0.25rem * 0)","bottom":"calc(0.25rem * 0)","left":"calc(0.25rem * 0)","height":"100%","width":"100cqi","max-width":"none","object-fit":"cover","object-position":"center"},"@supports (-webkit-overflow-scrolling: touch) and (overflow: -webkit-paged-x)":{"&:after":{"--tw-content":"none","content":"var(--tw-content)"}}}},".diff-item-1":{"@layer daisyui.l1.l2.l3":{"position":"relative","z-index":1,"grid-column-start":"1","grid-row":"span 3 / span 3","grid-row-start":"1","overflow":"hidden","border-right":"2px solid var(--color-base-100)","&:focus-visible":{"--tw-outline-style":"none","outline-style":"none"},"> *":{"pointer-events":"none","position":"absolute","top":"calc(0.25rem * 0)","bottom":"calc(0.25rem * 0)","left":"calc(0.25rem * 0)","height":"100%","width":"100cqi","max-width":"none","object-fit":"cover","object-position":"center"}}}};