export default {".breadcrumbs":{"@layer daisyui.l1.l2.l3":{"max-width":"100%","overflow-x":"auto","padding-block":"calc(0.25rem * 2)","> menu, > ul, > ol":{"display":"flex","min-height":"min-content","align-items":"center","white-space":"nowrap","> li":{"display":"flex","align-items":"center","> *":{"display":"flex","cursor":"pointer","align-items":"center","gap":"calc(0.25rem * 2)","&:hover":{"@media (hover: hover)":{"text-decoration-line":"underline"}},"&:focus":{"--tw-outline-style":"none","outline-style":"none","@media (forced-colors: active)":{"outline":"2px solid transparent","outline-offset":"2px"}},"&:focus-visible":{"outline":"2px solid currentColor","outline-offset":"2px"}},"& + *:before":{"content":"\"\"","margin-right":"calc(0.25rem * 3)","margin-left":"calc(0.25rem * 2)","display":"block","height":"calc(0.25rem * 1.5)","width":"calc(0.25rem * 1.5)","opacity":"40%","rotate":"45deg","border-top":"1px solid","border-right":"1px solid","background-color":"#0000"},"[dir=\"rtl\"] & + *:before":{"rotate":"-135deg"}}}}}};