import fab from './object.js';
import { addPrefix } from '../../functions/addPrefix.js';

export default ({ addComponents, prefix = '' }) => {
  const prefixedfab = addPrefix(fab, prefix);
  addComponents({ ...prefixedfab });
};
