export default {".alert":{"border-width":"var(--border)","border-color":"var(--alert-border-color, var(--color-base-200))","@layer daisyui.l1.l2.l3":{"border-style":"solid","--alert-border-color":"var(--color-base-200)","display":"grid","align-items":"center","gap":"calc(0.25rem * 4)","border-radius":"var(--radius-box)","padding-inline":"calc(0.25rem * 4)","padding-block":"calc(0.25rem * 3)","color":"var(--color-base-content)","background-color":"var(--alert-color, var(--color-base-200))","justify-content":"start","justify-items":"start","grid-auto-flow":"column","grid-template-columns":"auto","text-align":"start","font-size":"0.875rem","line-height":"1.25rem","background-size":"auto, calc(var(--noise) * 100%)","background-image":"none, var(--fx-noise)","box-shadow":"0 3px 0 -2px oklch(100% 0 0 / calc(var(--depth) * 0.08)) inset, 0 1px color-mix( in oklab, color-mix(in oklab, #000 20%, var(--alert-color, var(--color-base-200))) calc(var(--depth) * 20%), #0000 ), 0 4px 3px -2px oklch(0% 0 0 / calc(var(--depth) * 0.08))","&:has(:nth-child(2))":{"grid-template-columns":"auto minmax(auto, 1fr)"}}},".alert-info":{"@layer daisyui.l1.l2":{"color":"var(--color-info-content)","--alert-border-color":"var(--color-info)","--alert-color":"var(--color-info)"}},".alert-success":{"@layer daisyui.l1.l2":{"color":"var(--color-success-content)","--alert-border-color":"var(--color-success)","--alert-color":"var(--color-success)"}},".alert-warning":{"@layer daisyui.l1.l2":{"color":"var(--color-warning-content)","--alert-border-color":"var(--color-warning)","--alert-color":"var(--color-warning)"}},".alert-error":{"@layer daisyui.l1.l2":{"color":"var(--color-error-content)","--alert-border-color":"var(--color-error)","--alert-color":"var(--color-error)"}},".alert-soft":{"@layer daisyui.l1":{"color":"var(--alert-color, var(--color-base-content))","background":"color-mix( in oklab, var(--alert-color, var(--color-base-content)) 8%, var(--color-base-100) )","--alert-border-color":"color-mix(\n      in oklab,\n      var(--alert-color, var(--color-base-content)) 10%,\n      var(--color-base-100)\n    )","box-shadow":"none","background-image":"none"}},".alert-outline":{"@layer daisyui.l1":{"background-color":"transparent","color":"var(--alert-color)","box-shadow":"none","background-image":"none"}},".alert-dash":{"@layer daisyui.l1":{"background-color":"transparent","color":"var(--alert-color)","border-style":"dashed","box-shadow":"none","background-image":"none"}},".alert-vertical":{"@layer daisyui.l1.l2":{"justify-content":"center","justify-items":"center","grid-auto-flow":"row","grid-template-columns":"auto","text-align":"center","&:has(:nth-child(2))":{"grid-template-columns":"auto"}}},".alert-horizontal":{"@layer daisyui.l1.l2":{"justify-content":"start","justify-items":"start","grid-auto-flow":"column","grid-template-columns":"auto","text-align":"start","&:has(:nth-child(2))":{"grid-template-columns":"auto minmax(auto, 1fr)"}}}};