import tooltip from './object.js';
import { addPrefix } from '../../functions/addPrefix.js';

export default ({ addComponents, prefix = '' }) => {
  const prefixedtooltip = addPrefix(tooltip, prefix);
  addComponents({ ...prefixedtooltip });
};
