export default {".fieldset":{"@layer daisyui.l1.l2.l3":{"display":"grid","gap":"calc(0.25rem * 1.5)","padding-block":"calc(0.25rem * 1)","font-size":"0.75rem","grid-template-columns":"1fr","grid-auto-rows":"max-content"}},".fieldset-legend":{"@layer daisyui.l1.l2.l3":{"margin-bottom":"calc(0.25rem * -1)","display":"flex","align-items":"center","justify-content":"space-between","gap":"calc(0.25rem * 2)","padding-block":"calc(0.25rem * 2)","color":"var(--color-base-content)","font-weight":600}},".fieldset-label":{"@layer daisyui.l1.l2.l3":{"display":"flex","align-items":"center","gap":"calc(0.25rem * 1.5)","color":"color-mix(in oklab, var(--color-base-content) 60%, transparent)","&:has(input)":{"cursor":"pointer"}}}};