export default {".link":{"@layer daisyui.l1.l2.l3":{"cursor":"pointer","text-decoration-line":"underline","&:focus":{"--tw-outline-style":"none","outline-style":"none","@media (forced-colors: active)":{"outline":"2px solid transparent","outline-offset":"2px"}},"&:focus-visible":{"outline":"2px solid currentColor","outline-offset":"2px"}}},".link-hover":{"@layer daisyui.l1.l2":{"text-decoration-line":"none","&:hover":{"@media (hover: hover)":{"text-decoration-line":"underline"}}}},".link-primary":{"@layer daisyui.l1.l2":{"color":"var(--color-primary)","@media (hover: hover)":{"&:hover":{"color":"color-mix(in oklab, var(--color-primary) 80%, #000)"}}}},".link-secondary":{"@layer daisyui.l1.l2":{"color":"var(--color-secondary)","@media (hover: hover)":{"&:hover":{"color":"color-mix(in oklab, var(--color-secondary) 80%, #000)"}}}},".link-accent":{"@layer daisyui.l1.l2":{"color":"var(--color-accent)","@media (hover: hover)":{"&:hover":{"color":"color-mix(in oklab, var(--color-accent) 80%, #000)"}}}},".link-neutral":{"@layer daisyui.l1.l2":{"color":"var(--color-neutral)","@media (hover: hover)":{"&:hover":{"color":"color-mix(in oklab, var(--color-neutral) 80%, #000)"}}}},".link-success":{"@layer daisyui.l1.l2":{"color":"var(--color-success)","@media (hover: hover)":{"&:hover":{"color":"color-mix(in oklab, var(--color-success) 80%, #000)"}}}},".link-info":{"@layer daisyui.l1.l2":{"color":"var(--color-info)","@media (hover: hover)":{"&:hover":{"color":"color-mix(in oklab, var(--color-info) 80%, #000)"}}}},".link-warning":{"@layer daisyui.l1.l2":{"color":"var(--color-warning)","@media (hover: hover)":{"&:hover":{"color":"color-mix(in oklab, var(--color-warning) 80%, #000)"}}}},".link-error":{"@layer daisyui.l1.l2":{"color":"var(--color-error)","@media (hover: hover)":{"&:hover":{"color":"color-mix(in oklab, var(--color-error) 80%, #000)"}}}}};