export default {".filter":{"@layer daisyui.l1.l2.l3":{"display":"flex","flex-wrap":"wrap","input[type=\"radio\"]":{"width":"auto"},"input":{"overflow":"hidden","opacity":"100%","scale":"1","transition":"margin 0.1s, opacity 0.3s, padding 0.3s, border-width 0.1s","&:not(:last-child)":{"margin-inline-end":"calc(0.25rem * 1)"},"&.filter-reset":{"aspect-ratio":"1 / 1","&::after":{"--tw-content":"\"×\"","content":"var(--tw-content)"}}},"&:not(:has(input:checked:not(.filter-reset)))":{".filter-reset, input[type=\"reset\"]":{"scale":"0","border-width":"0","margin-inline":"calc(0.25rem * 0)","width":"calc(0.25rem * 0)","padding-inline":"calc(0.25rem * 0)","opacity":"0%"}},"&:has(input:checked:not(.filter-reset))":{"input:not(:checked, .filter-reset, input[type=\"reset\"])":{"scale":"0","border-width":"0","margin-inline":"calc(0.25rem * 0)","width":"calc(0.25rem * 0)","padding-inline":"calc(0.25rem * 0)","opacity":"0%"}}}}};