/*! 🌼 daisyUI 5.5.4 - MIT License */ @layer utilities{.mockup-code{@layer daisyui.l1.l2.l3{&{border-radius:var(--radius-box);background-color:var(--color-neutral);color:var(--color-neutral-content);direction:ltr;padding-block:1.25rem;font-size:.875rem;position:relative;overflow:auto hidden}&:before{content:"";opacity:.3;border-radius:3.40282e38px;width:.75rem;height:.75rem;margin-bottom:1rem;display:block;box-shadow:1.4em 0,2.8em 0,4.2em 0}& pre{padding-right:1.25rem;&:before{content:"";margin-right:2ch}&[data-prefix]{&:before{--tw-content:attr(data-prefix);content:var(--tw-content);text-align:right;opacity:.5;width:2rem;display:inline-block}}}}}.mockup-window{@layer daisyui.l1.l2.l3{&{border-radius:var(--radius-box);flex-direction:column;padding-top:1.25rem;display:flex;position:relative;overflow:auto hidden}&:before{content:"";aspect-ratio:1;opacity:.3;border-radius:3.40282e38px;flex-shrink:0;align-self:flex-start;height:.75rem;margin-bottom:1rem;display:block;box-shadow:1.4em 0,2.8em 0,4.2em 0}[dir=rtl] &:before{align-self:flex-end}& pre[data-prefix]{&:before{--tw-content:attr(data-prefix);content:var(--tw-content);text-align:right;display:inline-block}}}}.mockup-browser{@layer daisyui.l1.l2.l3{&{border-radius:var(--radius-box);position:relative;overflow:auto hidden}& pre[data-prefix]{&:before{--tw-content:attr(data-prefix);content:var(--tw-content);text-align:right;display:inline-block}}& .mockup-browser-toolbar{align-items:center;width:100%;margin-block:.75rem;padding-right:1.4em;display:inline-flex;&:where(:dir(rtl),[dir=rtl],[dir=rtl] *){flex-direction:row-reverse}&:before{content:"";aspect-ratio:1;opacity:.3;border-radius:3.40282e38px;height:.75rem;margin-right:4.8rem;display:inline-block;box-shadow:1.4em 0,2.8em 0,4.2em 0}& .input{background-color:var(--color-base-200);text-overflow:ellipsis;white-space:nowrap;direction:ltr;align-items:center;gap:.5rem;height:100%;margin-inline:auto;font-size:.75rem;display:flex;overflow:hidden;&:before{content:"";opacity:.5;background-color:currentColor;width:1rem;height:1rem;mask:url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'%3E%3Cpath fill-rule='evenodd' d='M9.965 11.026a5 5 0 1 1 1.06-1.06l2.755 2.754a.75.75 0 1 1-1.06 1.06l-2.755-2.754ZM10.5 7a3.5 3.5 0 1 1-7 0 3.5 3.5 0 0 1 7 0Z' clip-rule='evenodd' /%3E%3C/svg%3E") 50%/contain no-repeat}}}}}.mockup-phone{@layer daisyui.l1.l2.l3{&{aspect-ratio:462/978;background-color:#000;border:5px solid #6b6b6b;border-radius:65px;justify-items:center;width:100%;max-width:462px;padding:6px;display:inline-grid;overflow:hidden}@supports (corner-shape:superellipse(1.45)){&{corner-shape:superellipse(1.45);border-radius:90px}}}}.mockup-phone-camera{@layer daisyui.l1.l2.l3{&{z-index:1;background:#000;border-radius:17px;grid-area:1/1/1/1;width:28%;height:3.7%;margin-top:3%}}}.mockup-phone-display{@layer daisyui.l1.l2.l3{&{border-radius:54px;grid-area:1/1/1/1;width:100%;height:100%;overflow:hidden}@supports (corner-shape:superellipse(1.87)){&{corner-shape:superellipse(1.87);border-radius:101px}}&>img{object-fit:cover;width:100%;height:100%}}}}