export default {".avatar-group":{"@layer daisyui.l1.l2.l3":{"display":"flex","overflow":"hidden",".avatar":{"overflow":"hidden","border-radius":"calc(infinity * 1px)","border":"4px solid var(--color-base-100)"}}},".avatar":{"@layer daisyui.l1.l2.l3":{"position":"relative","display":"inline-flex","vertical-align":"middle","& > div":{"display":"block","aspect-ratio":"1 / 1","overflow":"hidden"},"img":{"height":"100%","width":"100%","object-fit":"cover"}}},".avatar-placeholder":{"@layer daisyui.l1.l2":{"& > div":{"display":"flex","align-items":"center","justify-content":"center"}}},".avatar-online":{"@layer daisyui.l1.l2":{"&:before":{"content":"\"\"","position":"absolute","z-index":1,"display":"block","border-radius":"calc(infinity * 1px)","background-color":"var(--color-success)","outline":"2px solid var(--color-base-100)","width":"15%","height":"15%","top":"7%","right":"7%"}}},".avatar-offline":{"@layer daisyui.l1.l2":{"&:before":{"content":"\"\"","position":"absolute","z-index":1,"display":"block","border-radius":"calc(infinity * 1px)","background-color":"var(--color-base-300)","outline":"2px solid var(--color-base-100)","width":"15%","height":"15%","top":"7%","right":"7%"}}}};