export default {".kbd":{"box-shadow":"none","@layer daisyui.l1.l2.l3":{"display":"inline-flex","align-items":"center","justify-content":"center","border-radius":"var(--radius-field)","background-color":"var(--color-base-200)","vertical-align":"middle","padding-left":"0.5em","padding-right":"0.5em","border":"var(--border) solid color-mix(in srgb, var(--color-base-content) 20%, #0000)","border-bottom":"calc(var(--border) + 1px) solid color-mix(in srgb, var(--color-base-content) 20%, #0000)","--size":"calc(var(--size-selector, 0.25rem) * 6)","font-size":"0.875rem","height":"var(--size)","min-width":"var(--size)"}},".kbd-xs":{"@layer daisyui.l1.l2":{"--size":"calc(var(--size-selector, 0.25rem) * 4)","font-size":"0.625rem"}},".kbd-sm":{"@layer daisyui.l1.l2":{"--size":"calc(var(--size-selector, 0.25rem) * 5)","font-size":"0.75rem"}},".kbd-md":{"@layer daisyui.l1.l2":{"--size":"calc(var(--size-selector, 0.25rem) * 6)","font-size":"0.875rem"}},".kbd-lg":{"@layer daisyui.l1.l2":{"--size":"calc(var(--size-selector, 0.25rem) * 7)","font-size":"1rem"}},".kbd-xl":{"@layer daisyui.l1.l2":{"--size":"calc(var(--size-selector, 0.25rem) * 8)","font-size":"1.125rem"}}};