export default {".toast":{"@layer daisyui.l1.l2.l3":{"position":"fixed","inset-inline-start":"auto","inset-inline-end":"calc(0.25rem * 4)","top":"auto","bottom":"calc(0.25rem * 4)","display":"flex","flex-direction":"column","gap":"calc(0.25rem * 2)","background-color":"transparent","translate":"var(--toast-x, 0) var(--toast-y, 0)","width":"max-content","max-width":"calc(100vw - 2rem)","& > *":{"@media (prefers-reduced-motion: no-preference)":{"animation":"toast 0.25s ease-out"}}}},".toast-start":{"@layer daisyui.l1.l2":{"inset-inline-start":"calc(0.25rem * 4)","inset-inline-end":"auto","--toast-x":"0"}},".toast-center":{"@layer daisyui.l1.l2":{"inset-inline-start":"calc(1/2 * 100%)","inset-inline-end":"calc(1/2 * 100%)","--toast-x":"-50%"}},".toast-end":{"@layer daisyui.l1.l2":{"inset-inline-start":"auto","inset-inline-end":"calc(0.25rem * 4)","--toast-x":"0"}},".toast-bottom":{"@layer daisyui.l1.l2":{"top":"auto","bottom":"calc(0.25rem * 4)","--toast-y":"0"}},".toast-middle":{"@layer daisyui.l1.l2":{"top":"calc(1/2 * 100%)","bottom":"auto","--toast-y":"-50%"}},".toast-top":{"@layer daisyui.l1.l2":{"top":"calc(0.25rem * 4)","bottom":"auto","--toast-y":"0"}},"@keyframes toast":{"0%":{"scale":"0.9","opacity":0},"100%":{"scale":"1","opacity":1}}};