export default {".dropdown":{"@layer daisyui.l1.l2.l3":{"position":"relative","display":"inline-block","position-area":"var(--anchor-v, bottom) var(--anchor-h, span-right)","& > *:not(:has(~ [class*=\"dropdown-content\"])):focus":{"--tw-outline-style":"none","outline-style":"none","@media (forced-colors: active)":{"outline":"2px solid transparent","outline-offset":"2px"}},".dropdown-content":{"position":"absolute"},"&.dropdown-close .dropdown-content, &:not(details, .dropdown-open, .dropdown-hover:hover, :focus-within) .dropdown-content, &.dropdown-hover:not(:hover) [tabindex]:first-child:focus:not(:focus-visible) ~ .dropdown-content":{"display":"none","transform-origin":"top","opacity":"0%","scale":"95%"},"&[popover], .dropdown-content":{"z-index":999,"@media (prefers-reduced-motion: no-preference)":{"animation":"dropdown 0.2s","transition-property":"opacity, scale, display","transition-behavior":"allow-discrete","transition-duration":"0.2s","transition-timing-function":"cubic-bezier(0.4, 0, 0.2, 1)"}},"@starting-style":{"&[popover], .dropdown-content":{"scale":"95%","opacity":0}},"&:not(.dropdown-close)":{"&.dropdown-open, &:not(.dropdown-hover):focus, &:focus-within":{"> [tabindex]:first-child":{"pointer-events":"none"},".dropdown-content":{"opacity":"100%","scale":"100%"}},"&.dropdown-hover:hover":{".dropdown-content":{"opacity":"100%","scale":"100%"}}},"&:is(details)":{"summary":{"&::-webkit-details-marker":{"display":"none"}}},"&:where([popover])":{"background":"#0000"},"&[popover]":{"position":"fixed","color":"inherit","@supports not (position-area: bottom)":{"margin":"auto","&.dropdown-close, &.dropdown-open:not(:popover-open)":{"display":"none","transform-origin":"top","opacity":"0%","scale":"95%"},"&::backdrop":{"background-color":"color-mix(in oklab, #000 30%, #0000)"}},"&.dropdown-close, &:not(.dropdown-open, :popover-open)":{"display":"none","transform-origin":"top","opacity":"0%","scale":"95%"}}}},".dropdown-start":{"@layer daisyui.l1.l2":{"--anchor-h":"span-right",":where(.dropdown-content)":{"inset-inline-end":"auto","translate":"0 0","[dir=\"rtl\"] &":{"translate":"0 0"}},"&.dropdown-left":{"--anchor-h":"left","--anchor-v":"span-bottom",".dropdown-content":{"top":"calc(0.25rem * 0)","bottom":"auto"}},"&.dropdown-right":{"--anchor-h":"right","--anchor-v":"span-bottom",".dropdown-content":{"top":"calc(0.25rem * 0)","bottom":"auto"}}}},".dropdown-center":{"@layer daisyui.l1.l2":{"--anchor-h":"center",":where(.dropdown-content)":{"inset-inline-end":"calc(1/2 * 100%)","translate":"50% 0","[dir=\"rtl\"] &":{"translate":"-50% 0"}},"&.dropdown-left":{"--anchor-h":"left","--anchor-v":"center",".dropdown-content":{"top":"auto","bottom":"calc(1/2 * 100%)","translate":"0 50%"}},"&.dropdown-right":{"--anchor-h":"right","--anchor-v":"center",".dropdown-content":{"top":"auto","bottom":"calc(1/2 * 100%)","translate":"0 50%"}}}},".dropdown-end":{"@layer daisyui.l1.l2":{"--anchor-h":"span-left",":where(.dropdown-content)":{"inset-inline-end":"calc(0.25rem * 0)","translate":"0 0","[dir=\"rtl\"] &":{"translate":"0 0"}},"&.dropdown-left":{"--anchor-h":"left","--anchor-v":"span-top",".dropdown-content":{"top":"auto","bottom":"calc(0.25rem * 0)"}},"&.dropdown-right":{"--anchor-h":"right","--anchor-v":"span-top",".dropdown-content":{"top":"auto","bottom":"calc(0.25rem * 0)"}}}},".dropdown-left":{"@layer daisyui.l1.l2":{"--anchor-h":"left","--anchor-v":"span-bottom",".dropdown-content":{"inset-inline-end":"100%","top":"calc(0.25rem * 0)","bottom":"auto","transform-origin":"100%"}}},".dropdown-right":{"@layer daisyui.l1.l2":{"--anchor-h":"right","--anchor-v":"span-bottom",".dropdown-content":{"inset-inline-start":"100%","top":"calc(0.25rem * 0)","bottom":"auto","transform-origin":"0"}}},".dropdown-bottom":{"@layer daisyui.l1.l2":{"--anchor-v":"bottom",".dropdown-content":{"top":"100%","bottom":"auto","transform-origin":"top"}}},".dropdown-top":{"@layer daisyui.l1.l2":{"--anchor-v":"top",".dropdown-content":{"top":"auto","bottom":"100%","transform-origin":"bottom"}}},"@keyframes dropdown":{"0%":{"opacity":0}}};