/*! 🌼 daisyUI 5.5.4 - MIT License */ @layer utilities{.fieldset{@layer daisyui.l1.l2.l3{&{grid-template-columns:1fr;grid-auto-rows:max-content;gap:.375rem;padding-block:.25rem;font-size:.75rem;display:grid}}}.fieldset-legend{@layer daisyui.l1.l2.l3{&{color:var(--color-base-content);justify-content:space-between;align-items:center;gap:.5rem;margin-bottom:-.25rem;padding-block:.5rem;font-weight:600;display:flex}}}.fieldset-label{@layer daisyui.l1.l2.l3{&{color:color-mix(in oklab,var(--color-base-content)60%,transparent);align-items:center;gap:.375rem;display:flex}&:has(input){cursor:pointer}}}@media (width>=640px){.sm\:fieldset{@layer daisyui.l1.l2.l3{&{grid-template-columns:1fr;grid-auto-rows:max-content;gap:.375rem;padding-block:.25rem;font-size:.75rem;display:grid}}}.sm\:fieldset-legend{@layer daisyui.l1.l2.l3{&{color:var(--color-base-content);justify-content:space-between;align-items:center;gap:.5rem;margin-bottom:-.25rem;padding-block:.5rem;font-weight:600;display:flex}}}.sm\:fieldset-label{@layer daisyui.l1.l2.l3{&{color:color-mix(in oklab,var(--color-base-content)60%,transparent);align-items:center;gap:.375rem;display:flex}&:has(input){cursor:pointer}}}}@media (width>=768px){.md\:fieldset{@layer daisyui.l1.l2.l3{&{grid-template-columns:1fr;grid-auto-rows:max-content;gap:.375rem;padding-block:.25rem;font-size:.75rem;display:grid}}}.md\:fieldset-legend{@layer daisyui.l1.l2.l3{&{color:var(--color-base-content);justify-content:space-between;align-items:center;gap:.5rem;margin-bottom:-.25rem;padding-block:.5rem;font-weight:600;display:flex}}}.md\:fieldset-label{@layer daisyui.l1.l2.l3{&{color:color-mix(in oklab,var(--color-base-content)60%,transparent);align-items:center;gap:.375rem;display:flex}&:has(input){cursor:pointer}}}}@media (width>=1024px){.lg\:fieldset{@layer daisyui.l1.l2.l3{&{grid-template-columns:1fr;grid-auto-rows:max-content;gap:.375rem;padding-block:.25rem;font-size:.75rem;display:grid}}}.lg\:fieldset-legend{@layer daisyui.l1.l2.l3{&{color:var(--color-base-content);justify-content:space-between;align-items:center;gap:.5rem;margin-bottom:-.25rem;padding-block:.5rem;font-weight:600;display:flex}}}.lg\:fieldset-label{@layer daisyui.l1.l2.l3{&{color:color-mix(in oklab,var(--color-base-content)60%,transparent);align-items:center;gap:.375rem;display:flex}&:has(input){cursor:pointer}}}}@media (width>=1280px){.xl\:fieldset{@layer daisyui.l1.l2.l3{&{grid-template-columns:1fr;grid-auto-rows:max-content;gap:.375rem;padding-block:.25rem;font-size:.75rem;display:grid}}}.xl\:fieldset-legend{@layer daisyui.l1.l2.l3{&{color:var(--color-base-content);justify-content:space-between;align-items:center;gap:.5rem;margin-bottom:-.25rem;padding-block:.5rem;font-weight:600;display:flex}}}.xl\:fieldset-label{@layer daisyui.l1.l2.l3{&{color:color-mix(in oklab,var(--color-base-content)60%,transparent);align-items:center;gap:.375rem;display:flex}&:has(input){cursor:pointer}}}}@media (width>=1536px){.\32 xl\:fieldset{@layer daisyui.l1.l2.l3{&{grid-template-columns:1fr;grid-auto-rows:max-content;gap:.375rem;padding-block:.25rem;font-size:.75rem;display:grid}}}.\32 xl\:fieldset-legend{@layer daisyui.l1.l2.l3{&{color:var(--color-base-content);justify-content:space-between;align-items:center;gap:.5rem;margin-bottom:-.25rem;padding-block:.5rem;font-weight:600;display:flex}}}.\32 xl\:fieldset-label{@layer daisyui.l1.l2.l3{&{color:color-mix(in oklab,var(--color-base-content)60%,transparent);align-items:center;gap:.375rem;display:flex}&:has(input){cursor:pointer}}}}}