/*! 🌼 daisyUI 5.5.4 - MIT License */ @layer utilities{.navbar{@layer daisyui.l1.l2.l3{&{align-items:center;width:100%;min-height:4rem;padding:.5rem;display:flex}}}:where(.navbar){@layer daisyui.l1.l2{&{position:relative}}}.navbar-start{@layer daisyui.l1.l2.l3{&{justify-content:flex-start;align-items:center;width:50%;display:inline-flex}}}.navbar-center{@layer daisyui.l1.l2.l3{&{flex-shrink:0;align-items:center;display:inline-flex}}}.navbar-end{@layer daisyui.l1.l2.l3{&{justify-content:flex-end;align-items:center;width:50%;display:inline-flex}}}@media (width>=640px){.sm\:navbar{@layer daisyui.l1.l2.l3{&{align-items:center;width:100%;min-height:4rem;padding:.5rem;display:flex}}}:where(.navbar){@layer daisyui.l1.l2{&{position:relative}}}.sm\:navbar-start{@layer daisyui.l1.l2.l3{&{justify-content:flex-start;align-items:center;width:50%;display:inline-flex}}}.sm\:navbar-center{@layer daisyui.l1.l2.l3{&{flex-shrink:0;align-items:center;display:inline-flex}}}.sm\:navbar-end{@layer daisyui.l1.l2.l3{&{justify-content:flex-end;align-items:center;width:50%;display:inline-flex}}}}@media (width>=768px){.md\:navbar{@layer daisyui.l1.l2.l3{&{align-items:center;width:100%;min-height:4rem;padding:.5rem;display:flex}}}:where(.navbar){@layer daisyui.l1.l2{&{position:relative}}}.md\:navbar-start{@layer daisyui.l1.l2.l3{&{justify-content:flex-start;align-items:center;width:50%;display:inline-flex}}}.md\:navbar-center{@layer daisyui.l1.l2.l3{&{flex-shrink:0;align-items:center;display:inline-flex}}}.md\:navbar-end{@layer daisyui.l1.l2.l3{&{justify-content:flex-end;align-items:center;width:50%;display:inline-flex}}}}@media (width>=1024px){.lg\:navbar{@layer daisyui.l1.l2.l3{&{align-items:center;width:100%;min-height:4rem;padding:.5rem;display:flex}}}:where(.navbar){@layer daisyui.l1.l2{&{position:relative}}}.lg\:navbar-start{@layer daisyui.l1.l2.l3{&{justify-content:flex-start;align-items:center;width:50%;display:inline-flex}}}.lg\:navbar-center{@layer daisyui.l1.l2.l3{&{flex-shrink:0;align-items:center;display:inline-flex}}}.lg\:navbar-end{@layer daisyui.l1.l2.l3{&{justify-content:flex-end;align-items:center;width:50%;display:inline-flex}}}}@media (width>=1280px){.xl\:navbar{@layer daisyui.l1.l2.l3{&{align-items:center;width:100%;min-height:4rem;padding:.5rem;display:flex}}}:where(.navbar){@layer daisyui.l1.l2{&{position:relative}}}.xl\:navbar-start{@layer daisyui.l1.l2.l3{&{justify-content:flex-start;align-items:center;width:50%;display:inline-flex}}}.xl\:navbar-center{@layer daisyui.l1.l2.l3{&{flex-shrink:0;align-items:center;display:inline-flex}}}.xl\:navbar-end{@layer daisyui.l1.l2.l3{&{justify-content:flex-end;align-items:center;width:50%;display:inline-flex}}}}@media (width>=1536px){.\32 xl\:navbar{@layer daisyui.l1.l2.l3{&{align-items:center;width:100%;min-height:4rem;padding:.5rem;display:flex}}}:where(.navbar){@layer daisyui.l1.l2{&{position:relative}}}.\32 xl\:navbar-start{@layer daisyui.l1.l2.l3{&{justify-content:flex-start;align-items:center;width:50%;display:inline-flex}}}.\32 xl\:navbar-center{@layer daisyui.l1.l2.l3{&{flex-shrink:0;align-items:center;display:inline-flex}}}.\32 xl\:navbar-end{@layer daisyui.l1.l2.l3{&{justify-content:flex-end;align-items:center;width:50%;display:inline-flex}}}}}