export default {".status":{"@layer daisyui.l1.l2.l3":{"display":"inline-block","aspect-ratio":"1 / 1","width":"calc(0.25rem * 2)","height":"calc(0.25rem * 2)","border-radius":"var(--radius-selector)","background-color":"color-mix(in oklab, var(--color-base-content) 20%, transparent)","background-position":"center","background-repeat":"no-repeat","vertical-align":"middle","color":"color-mix(in oklab, var(--color-black) 30%, transparent)","background-image":"radial-gradient( circle at 35% 30%, oklch(1 0 0 / calc(var(--depth) * 0.5)), #0000 )","box-shadow":"0 2px 3px -1px color-mix(in oklab, currentColor calc(var(--depth) * 100%), #0000)"}},".status-primary":{"@layer daisyui.l1.l2":{"background-color":"var(--color-primary)","color":"var(--color-primary)"}},".status-secondary":{"@layer daisyui.l1.l2":{"background-color":"var(--color-secondary)","color":"var(--color-secondary)"}},".status-accent":{"@layer daisyui.l1.l2":{"background-color":"var(--color-accent)","color":"var(--color-accent)"}},".status-neutral":{"@layer daisyui.l1.l2":{"background-color":"var(--color-neutral)","color":"var(--color-neutral)"}},".status-info":{"@layer daisyui.l1.l2":{"background-color":"var(--color-info)","color":"var(--color-info)"}},".status-success":{"@layer daisyui.l1.l2":{"background-color":"var(--color-success)","color":"var(--color-success)"}},".status-warning":{"@layer daisyui.l1.l2":{"background-color":"var(--color-warning)","color":"var(--color-warning)"}},".status-error":{"@layer daisyui.l1.l2":{"background-color":"var(--color-error)","color":"var(--color-error)"}},".status-xs":{"@layer daisyui.l1.l2":{"width":"calc(0.25rem * 0.5)","height":"calc(0.25rem * 0.5)"}},".status-sm":{"@layer daisyui.l1.l2":{"width":"calc(0.25rem * 1)","height":"calc(0.25rem * 1)"}},".status-md":{"@layer daisyui.l1.l2":{"width":"calc(0.25rem * 2)","height":"calc(0.25rem * 2)"}},".status-lg":{"@layer daisyui.l1.l2":{"width":"calc(0.25rem * 3)","height":"calc(0.25rem * 3)"}},".status-xl":{"@layer daisyui.l1.l2":{"width":"calc(0.25rem * 4)","height":"calc(0.25rem * 4)"}}};