export default {".textarea":{"@layer daisyui.l1.l2.l3":{"border":"var(--border) solid #0000","min-height":"calc(0.25rem * 20)","flex-shrink":1,"appearance":"none","border-radius":"var(--radius-field)","background-color":"var(--color-base-100)","padding-block":"calc(0.25rem * 2)","vertical-align":"middle","width":"clamp(3rem, 20rem, 100%)","padding-inline-start":"0.75rem","padding-inline-end":"0.75rem","font-size":"max(var(--font-size, 0.875rem), 0.875rem)","touch-action":"manipulation","border-color":"var(--input-color)","box-shadow":"0 1px color-mix(in oklab, var(--input-color) calc(var(--depth) * 10%), #0000) inset, 0 -1px oklch(100% 0 0 / calc(var(--depth) * 0.1)) inset","--input-color":"color-mix(in oklab, var(--color-base-content) 20%, #0000)","textarea":{"appearance":"none","background-color":"transparent","border":"none","&:focus, &:focus-within":{"--tw-outline-style":"none","outline-style":"none","@media (forced-colors: active)":{"outline":"2px solid transparent","outline-offset":"2px"}}},"&:focus, &:focus-within":{"--input-color":"var(--color-base-content)","box-shadow":"0 1px color-mix(in oklab, var(--input-color) calc(var(--depth) * 10%), #0000)","outline":"2px solid var(--input-color)","outline-offset":"2px","isolation":"isolate"},"@media (pointer: coarse)":{"@supports (-webkit-touch-callout: none)":{"&:focus, &:focus-within":{"--font-size":"1rem"}}},"&:has(> textarea[disabled]), &:is(:disabled, [disabled])":{"cursor":"not-allowed","border-color":"var(--color-base-200)","background-color":"var(--color-base-200)","color":"color-mix(in oklab, var(--color-base-content) 40%, transparent)","&::placeholder":{"color":"color-mix(in oklab, var(--color-base-content) 20%, transparent)"},"box-shadow":"none"},"&:has(> textarea[disabled]) > textarea[disabled]":{"cursor":"not-allowed"}}},".textarea-ghost":{"@layer daisyui.l1.l2":{"background-color":"transparent","box-shadow":"none","border-color":"#0000","&:focus, &:focus-within":{"background-color":"var(--color-base-100)","color":"var(--color-base-content)","border-color":"#0000","box-shadow":"none"}}},".textarea-neutral":{"@layer daisyui.l1.l2":{"&, &:focus, &:focus-within":{"--input-color":"var(--color-neutral)"}}},".textarea-primary":{"@layer daisyui.l1.l2":{"&, &:focus, &:focus-within":{"--input-color":"var(--color-primary)"}}},".textarea-secondary":{"@layer daisyui.l1.l2":{"&, &:focus, &:focus-within":{"--input-color":"var(--color-secondary)"}}},".textarea-accent":{"@layer daisyui.l1.l2":{"&, &:focus, &:focus-within":{"--input-color":"var(--color-accent)"}}},".textarea-info":{"@layer daisyui.l1.l2":{"&, &:focus, &:focus-within":{"--input-color":"var(--color-info)"}}},".textarea-success":{"@layer daisyui.l1.l2":{"&, &:focus, &:focus-within":{"--input-color":"var(--color-success)"}}},".textarea-warning":{"@layer daisyui.l1.l2":{"&, &:focus, &:focus-within":{"--input-color":"var(--color-warning)"}}},".textarea-error":{"@layer daisyui.l1.l2":{"&, &:focus, &:focus-within":{"--input-color":"var(--color-error)"}}},".textarea-xs":{"@layer daisyui.l1.l2":{"font-size":"max(var(--font-size, 0.6875rem), 0.6875rem)"}},".textarea-sm":{"@layer daisyui.l1.l2":{"font-size":"max(var(--font-size, 0.75rem), 0.75rem)"}},".textarea-md":{"@layer daisyui.l1.l2":{"font-size":"max(var(--font-size, 0.875rem), 0.875rem)"}},".textarea-lg":{"@layer daisyui.l1.l2":{"font-size":"max(var(--font-size, 1.125rem), 1.125rem)"}},".textarea-xl":{"@layer daisyui.l1.l2":{"font-size":"max(var(--font-size, 1.375rem), 1.375rem)"}}};