import drawer from './object.js';
import { addPrefix } from '../../functions/addPrefix.js';

export default ({ addComponents, prefix = '' }) => {
  const prefixeddrawer = addPrefix(drawer, prefix);
  addComponents({ ...prefixeddrawer });
};
