export default {".navbar":{"@layer daisyui.l1.l2.l3":{"display":"flex","width":"100%","align-items":"center","padding":"0.5rem","min-height":"4rem"}},":where(.navbar)":{"@layer daisyui.l1.l2":{"position":"relative"}},".navbar-start":{"@layer daisyui.l1.l2.l3":{"display":"inline-flex","align-items":"center","width":"50%","justify-content":"flex-start"}},".navbar-center":{"@layer daisyui.l1.l2.l3":{"display":"inline-flex","align-items":"center","flex-shrink":0}},".navbar-end":{"@layer daisyui.l1.l2.l3":{"display":"inline-flex","align-items":"center","width":"50%","justify-content":"flex-end"}}};