/*! 🌼 daisyUI 5.5.4 - MIT License */ @layer utilities{.stack{@layer daisyui.l1.l2.l3{&{grid-template-rows:3px 4px 1fr 4px 3px;grid-template-columns:3px 4px 1fr 4px 3px;display:inline-grid}&>*{width:100%;height:100%;&:nth-child(n+2){opacity:.7;width:100%}&:nth-child(2){z-index:2;opacity:.9}&:first-child{z-index:3;width:100%}}}@layer daisyui.l1.l2{&,&.stack-bottom{&>*{grid-area:3/3/6/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/1/4/6}}}&.stack-top{&>*{grid-area:1/3/4/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:3/1/6/6}}}&.stack-start{&>*{grid-area:3/1/4/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/3/6/6}}}&.stack-end{&>*{grid-area:3/3/4/6;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/1/6/4}}}}}@media (width>=640px){.sm\:stack{@layer daisyui.l1.l2.l3{&{grid-template-rows:3px 4px 1fr 4px 3px;grid-template-columns:3px 4px 1fr 4px 3px;display:inline-grid}&>*{width:100%;height:100%;&:nth-child(n+2){opacity:.7;width:100%}&:nth-child(2){z-index:2;opacity:.9}&:first-child{z-index:3;width:100%}}}@layer daisyui.l1.l2{&,&.stack-bottom{&>*{grid-area:3/3/6/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/1/4/6}}}&.stack-top{&>*{grid-area:1/3/4/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:3/1/6/6}}}&.stack-start{&>*{grid-area:3/1/4/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/3/6/6}}}&.stack-end{&>*{grid-area:3/3/4/6;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/1/6/4}}}}}}@media (width>=768px){.md\:stack{@layer daisyui.l1.l2.l3{&{grid-template-rows:3px 4px 1fr 4px 3px;grid-template-columns:3px 4px 1fr 4px 3px;display:inline-grid}&>*{width:100%;height:100%;&:nth-child(n+2){opacity:.7;width:100%}&:nth-child(2){z-index:2;opacity:.9}&:first-child{z-index:3;width:100%}}}@layer daisyui.l1.l2{&,&.stack-bottom{&>*{grid-area:3/3/6/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/1/4/6}}}&.stack-top{&>*{grid-area:1/3/4/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:3/1/6/6}}}&.stack-start{&>*{grid-area:3/1/4/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/3/6/6}}}&.stack-end{&>*{grid-area:3/3/4/6;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/1/6/4}}}}}}@media (width>=1024px){.lg\:stack{@layer daisyui.l1.l2.l3{&{grid-template-rows:3px 4px 1fr 4px 3px;grid-template-columns:3px 4px 1fr 4px 3px;display:inline-grid}&>*{width:100%;height:100%;&:nth-child(n+2){opacity:.7;width:100%}&:nth-child(2){z-index:2;opacity:.9}&:first-child{z-index:3;width:100%}}}@layer daisyui.l1.l2{&,&.stack-bottom{&>*{grid-area:3/3/6/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/1/4/6}}}&.stack-top{&>*{grid-area:1/3/4/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:3/1/6/6}}}&.stack-start{&>*{grid-area:3/1/4/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/3/6/6}}}&.stack-end{&>*{grid-area:3/3/4/6;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/1/6/4}}}}}}@media (width>=1280px){.xl\:stack{@layer daisyui.l1.l2.l3{&{grid-template-rows:3px 4px 1fr 4px 3px;grid-template-columns:3px 4px 1fr 4px 3px;display:inline-grid}&>*{width:100%;height:100%;&:nth-child(n+2){opacity:.7;width:100%}&:nth-child(2){z-index:2;opacity:.9}&:first-child{z-index:3;width:100%}}}@layer daisyui.l1.l2{&,&.stack-bottom{&>*{grid-area:3/3/6/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/1/4/6}}}&.stack-top{&>*{grid-area:1/3/4/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:3/1/6/6}}}&.stack-start{&>*{grid-area:3/1/4/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/3/6/6}}}&.stack-end{&>*{grid-area:3/3/4/6;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/1/6/4}}}}}}@media (width>=1536px){.\32 xl\:stack{@layer daisyui.l1.l2.l3{&{grid-template-rows:3px 4px 1fr 4px 3px;grid-template-columns:3px 4px 1fr 4px 3px;display:inline-grid}&>*{width:100%;height:100%;&:nth-child(n+2){opacity:.7;width:100%}&:nth-child(2){z-index:2;opacity:.9}&:first-child{z-index:3;width:100%}}}@layer daisyui.l1.l2{&,&.stack-bottom{&>*{grid-area:3/3/6/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/1/4/6}}}&.stack-top{&>*{grid-area:1/3/4/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:3/1/6/6}}}&.stack-start{&>*{grid-area:3/1/4/4;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/3/6/6}}}&.stack-end{&>*{grid-area:3/3/4/6;&:nth-child(2){grid-area:2/2/5/5}&:first-child{grid-area:1/1/6/4}}}}}}}