export default {".checkbox":{"@layer daisyui.l1.l2.l3":{"border":"var(--border) solid var(--input-color, color-mix(in oklab, var(--color-base-content) 20%, #0000))","position":"relative","display":"inline-block","flex-shrink":0,"cursor":"pointer","appearance":"none","border-radius":"var(--radius-selector)","padding":"calc(0.25rem * 1)","vertical-align":"middle","color":"var(--color-base-content)","box-shadow":"0 1px oklch(0% 0 0 / calc(var(--depth) * 0.1)) inset, 0 0 #0000 inset, 0 0 #0000","transition":"background-color 0.2s, box-shadow 0.2s","--size":"calc(var(--size-selector, 0.25rem) * 6)","width":"var(--size)","height":"var(--size)","background-size":"auto, calc(var(--noise) * 100%)","background-image":"none, var(--fx-noise)","&:before":{"--tw-content":"\"\"","content":"var(--tw-content)","display":"block","width":"100%","height":"100%","rotate":"45deg","background-color":"currentcolor","opacity":"0%","transition":"clip-path 0.3s, opacity 0.1s, rotate 0.3s, translate 0.3s","transition-delay":"0.1s","clip-path":"polygon(20% 100%, 20% 80%, 50% 80%, 50% 80%, 70% 80%, 70% 100%)","box-shadow":"0px 3px 0 0px oklch(100% 0 0 / calc(var(--depth) * 0.1)) inset","font-size":"1rem","line-height":0.75},"&:focus-visible":{"outline":"2px solid var(--input-color, currentColor)","outline-offset":"2px"},"&:checked, &[aria-checked=\"true\"]":{"background-color":"var(--input-color, #0000)","box-shadow":"0 0 #0000 inset, 0 8px 0 -4px oklch(100% 0 0 / calc(var(--depth) * 0.1)) inset, 0 1px oklch(0% 0 0 / calc(var(--depth) * 0.1))","&:before":{"clip-path":"polygon(20% 100%, 20% 80%, 50% 80%, 50% 0%, 70% 0%, 70% 100%)","opacity":"100%"},"@media (forced-colors: active)":{"&:before":{"rotate":"0deg","background-color":"transparent","--tw-content":"\"✔︎\"","clip-path":"none"}},"@media print":{"&:before":{"rotate":"0deg","background-color":"transparent","--tw-content":"\"✔︎\"","clip-path":"none"}}},"&:indeterminate":{"background-color":"var( --input-color, color-mix(in oklab, var(--color-base-content) 20%, #0000) )","&:before":{"rotate":"0deg","opacity":"100%","translate":"0 -35%","clip-path":"polygon(20% 100%, 20% 80%, 50% 80%, 50% 80%, 80% 80%, 80% 100%)"}}}},".checkbox-primary":{"@layer daisyui.l1.l2":{"color":"var(--color-primary-content)","--input-color":"var(--color-primary)"}},".checkbox-secondary":{"@layer daisyui.l1.l2":{"color":"var(--color-secondary-content)","--input-color":"var(--color-secondary)"}},".checkbox-accent":{"@layer daisyui.l1.l2":{"color":"var(--color-accent-content)","--input-color":"var(--color-accent)"}},".checkbox-neutral":{"@layer daisyui.l1.l2":{"color":"var(--color-neutral-content)","--input-color":"var(--color-neutral)"}},".checkbox-info":{"@layer daisyui.l1.l2":{"color":"var(--color-info-content)","--input-color":"var(--color-info)"}},".checkbox-success":{"@layer daisyui.l1.l2":{"color":"var(--color-success-content)","--input-color":"var(--color-success)"}},".checkbox-warning":{"@layer daisyui.l1.l2":{"color":"var(--color-warning-content)","--input-color":"var(--color-warning)"}},".checkbox-error":{"@layer daisyui.l1.l2":{"color":"var(--color-error-content)","--input-color":"var(--color-error)"}},".checkbox:disabled":{"@layer daisyui.l1.l2":{"cursor":"not-allowed","opacity":"20%"}},".checkbox-xs":{"@layer daisyui.l1.l2":{"padding":"0.125rem","--size":"calc(var(--size-selector, 0.25rem) * 4)"}},".checkbox-sm":{"@layer daisyui.l1.l2":{"padding":"0.1875rem","--size":"calc(var(--size-selector, 0.25rem) * 5)"}},".checkbox-md":{"@layer daisyui.l1.l2":{"padding":"0.25rem","--size":"calc(var(--size-selector, 0.25rem) * 6)"}},".checkbox-lg":{"@layer daisyui.l1.l2":{"padding":"0.3125rem","--size":"calc(var(--size-selector, 0.25rem) * 7)"}},".checkbox-xl":{"@layer daisyui.l1.l2":{"padding":"0.375rem","--size":"calc(var(--size-selector, 0.25rem) * 8)"}}};