export default {".hero":{"@layer daisyui.l1.l2.l3":{"display":"grid","width":"100%","place-items":"center","background-size":"cover","background-position":"center","& > *":{"grid-column-start":"1","grid-row-start":"1"}}},".hero-overlay":{"@layer daisyui.l1.l2.l3":{"grid-column-start":"1","grid-row-start":"1","height":"100%","width":"100%","background-color":"color-mix(in oklab, var(--color-neutral) 50%, transparent)"}},".hero-content":{"@layer daisyui.l1.l2.l3":{"isolation":"isolate","display":"flex","max-width":"80rem","align-items":"center","justify-content":"center","gap":"calc(0.25rem * 4)","padding":"calc(0.25rem * 4)"}}};