export default {".progress":{"@layer daisyui.l1.l2.l3":{"position":"relative","height":"calc(0.25rem * 2)","width":"100%","appearance":"none","overflow":"hidden","border-radius":"var(--radius-box)","background-color":"color-mix(in oklab, currentcolor 20%, transparent)","color":"var(--color-base-content)","&:indeterminate":{"background-image":"repeating-linear-gradient( 90deg, currentColor -1%, currentColor 10%, #0000 10%, #0000 90% )","background-size":"200%","background-position-x":"15%","@media (prefers-reduced-motion: no-preference)":{"animation":"progress 5s ease-in-out infinite"},"@supports (-moz-appearance: none)":{"&::-moz-progress-bar":{"background-color":"transparent","@media (prefers-reduced-motion: no-preference)":{"animation":"progress 5s ease-in-out infinite","background-image":"repeating-linear-gradient( 90deg, currentColor -1%, currentColor 10%, #0000 10%, #0000 90% )","background-size":"200%","background-position-x":"15%"}}}},"@supports (-moz-appearance: none)":{"&::-moz-progress-bar":{"border-radius":"var(--radius-box)","background-color":"currentcolor"}},"@supports (-webkit-appearance: none)":{"&::-webkit-progress-bar":{"border-radius":"var(--radius-box)","background-color":"transparent"},"&::-webkit-progress-value":{"border-radius":"var(--radius-box)","background-color":"currentColor"}}}},".progress-primary":{"@layer daisyui.l1.l2":{"color":"var(--color-primary)"}},".progress-secondary":{"@layer daisyui.l1.l2":{"color":"var(--color-secondary)"}},".progress-accent":{"@layer daisyui.l1.l2":{"color":"var(--color-accent)"}},".progress-neutral":{"@layer daisyui.l1.l2":{"color":"var(--color-neutral)"}},".progress-info":{"@layer daisyui.l1.l2":{"color":"var(--color-info)"}},".progress-success":{"@layer daisyui.l1.l2":{"color":"var(--color-success)"}},".progress-warning":{"@layer daisyui.l1.l2":{"color":"var(--color-warning)"}},".progress-error":{"@layer daisyui.l1.l2":{"color":"var(--color-error)"}},"@keyframes progress":{"50%":{"background-position-x":"-115%"}}};