export default {".modal":{"@layer daisyui.l1.l2.l3":{"pointer-events":"none","visibility":"hidden","position":"fixed","inset":"calc(0.25rem * 0)","margin":"calc(0.25rem * 0)","display":"grid","height":"100%","max-height":"none","width":"100%","max-width":"none","align-items":"center","justify-items":"center","background-color":"transparent","padding":"calc(0.25rem * 0)","color":"inherit","transition":"visibility 0.3s allow-discrete, background-color 0.3s ease-out, opacity 0.1s ease-out","overflow":"clip","overscroll-behavior":"contain","z-index":999,"scrollbar-gutter":"auto","&::backdrop":{"display":"none"}},"@layer daisyui.l1.l2":{"&.modal-open, &[open], &:target, .modal-toggle:checked + &":{"pointer-events":"auto","visibility":"visible","opacity":"100%","transition":"visibility 0s allow-discrete, background-color 0.3s ease-out, opacity 0.1s ease-out","background-color":"oklch(0% 0 0/ 0.4)",".modal-box":{"translate":"0 0","scale":"1","opacity":1},":root:has(&)":{"--page-has-backdrop":"1","--page-overflow":"hidden","--page-scroll-bg":"var(--page-scroll-bg-on)","--page-scroll-gutter":"stable","--page-scroll-transition":"var(--page-scroll-transition-on)","animation":"set-page-has-scroll forwards","animation-timeline":"scroll()"}},"@starting-style":{"&.modal-open, &[open], &:target, .modal-toggle:checked + &":{"opacity":"0%"}}}},".modal-action":{"@layer daisyui.l1.l2.l3":{"margin-top":"calc(0.25rem * 6)","display":"flex","justify-content":"flex-end","gap":"calc(0.25rem * 2)"}},".modal-toggle":{"@layer daisyui.l1.l2.l3":{"position":"fixed","height":"calc(0.25rem * 0)","width":"calc(0.25rem * 0)","appearance":"none","opacity":"0%"}},".modal-backdrop":{"@layer daisyui.l1.l2.l3":{"grid-column-start":"1","grid-row-start":"1","display":"grid","align-self":"stretch","justify-self":"stretch","color":"transparent","z-index":-1,"button":{"cursor":"pointer"}}},".modal-box":{"@layer daisyui.l1.l2.l3":{"grid-column-start":"1","grid-row-start":"1","max-height":"100vh","width":"calc(11/12 * 100%)","max-width":"32rem","background-color":"var(--color-base-100)","padding":"calc(0.25rem * 6)","transition":"translate 0.3s ease-out, scale 0.3s ease-out, opacity 0.2s ease-out 0.05s, box-shadow 0.3s ease-out","border-top-left-radius":"var(--modal-tl, var(--radius-box))","border-top-right-radius":"var(--modal-tr, var(--radius-box))","border-bottom-left-radius":"var(--modal-bl, var(--radius-box))","border-bottom-right-radius":"var(--modal-br, var(--radius-box))","scale":"95%","opacity":0,"box-shadow":"oklch(0% 0 0/ 0.25) 0px 25px 50px -12px","overflow-y":"auto","overscroll-behavior":"contain"}},".modal-top":{"@layer daisyui.l1.l2":{"place-items":"start",".modal-box":{"height":"auto","width":"100%","max-width":"none","max-height":"calc(100vh - 5em)","translate":"0 -100%","scale":"1","--modal-tl":"0","--modal-tr":"0","--modal-bl":"var(--radius-box)","--modal-br":"var(--radius-box)"}}},".modal-middle":{"@layer daisyui.l1.l2":{"place-items":"center",".modal-box":{"height":"auto","width":"calc(11/12 * 100%)","max-width":"32rem","max-height":"calc(100vh - 5em)","translate":"0 2%","scale":"98%","--modal-tl":"var(--radius-box)","--modal-tr":"var(--radius-box)","--modal-bl":"var(--radius-box)","--modal-br":"var(--radius-box)"}}},".modal-bottom":{"@layer daisyui.l1.l2":{"place-items":"end",".modal-box":{"height":"auto","width":"100%","max-width":"none","max-height":"calc(100vh - 5em)","translate":"0 100%","scale":"1","--modal-tl":"var(--radius-box)","--modal-tr":"var(--radius-box)","--modal-bl":"0","--modal-br":"0"}}},".modal-start":{"@layer daisyui.l1.l2":{"place-items":"start",".modal-box":{"height":"100vh","max-height":"none","width":"auto","max-width":"none","translate":"-100% 0","scale":"1","--modal-tl":"0","--modal-tr":"var(--radius-box)","--modal-bl":"0","--modal-br":"var(--radius-box)"}}},".modal-end":{"@layer daisyui.l1.l2":{"place-items":"end",".modal-box":{"height":"100vh","max-height":"none","width":"auto","max-width":"none","translate":"100% 0","scale":"1","--modal-tl":"var(--radius-box)","--modal-tr":"0","--modal-bl":"var(--radius-box)","--modal-br":"0"}}}};