export default {".chat":{"@layer daisyui.l1.l2.l3":{"display":"grid","column-gap":"calc(0.25rem * 3)","padding-block":"calc(0.25rem * 1)","--mask-chat":"url(\"data:image/svg+xml,%3csvg width='13' height='13' xmlns='http://www.w3.org/2000/svg'%3e%3cpath fill='black' d='M0 11.5004C0 13.0004 2 13.0004 2 13.0004H12H13V0.00036329L12.5 0C12.5 0 11.977 2.09572 11.8581 2.50033C11.6075 3.35237 10.9149 4.22374 9 5.50036C6 7.50036 0 10.0004 0 11.5004Z'/%3e%3c/svg%3e\")"}},".chat-bubble":{"@layer daisyui.l1.l2.l3":{"position":"relative","display":"block","width":"fit-content","border-radius":"var(--radius-field)","background-color":"var(--color-base-300)","padding-inline":"calc(0.25rem * 4)","padding-block":"calc(0.25rem * 2)","color":"var(--color-base-content)","grid-row-end":"3","min-height":"2rem","min-width":"2.5rem","max-width":"90%","&:before":{"position":"absolute","bottom":"calc(0.25rem * 0)","height":"calc(0.25rem * 3)","width":"calc(0.25rem * 3)","background-color":"inherit","content":"\"\"","mask-repeat":"no-repeat","mask-image":"var(--mask-chat)","mask-position":"0px -1px","mask-size":"0.8125rem"}}},".chat-bubble-primary":{"@layer daisyui.l1.l2":{"background-color":"var(--color-primary)","color":"var(--color-primary-content)"}},".chat-bubble-secondary":{"@layer daisyui.l1.l2":{"background-color":"var(--color-secondary)","color":"var(--color-secondary-content)"}},".chat-bubble-accent":{"@layer daisyui.l1.l2":{"background-color":"var(--color-accent)","color":"var(--color-accent-content)"}},".chat-bubble-neutral":{"@layer daisyui.l1.l2":{"background-color":"var(--color-neutral)","color":"var(--color-neutral-content)"}},".chat-bubble-info":{"@layer daisyui.l1.l2":{"background-color":"var(--color-info)","color":"var(--color-info-content)"}},".chat-bubble-success":{"@layer daisyui.l1.l2":{"background-color":"var(--color-success)","color":"var(--color-success-content)"}},".chat-bubble-warning":{"@layer daisyui.l1.l2":{"background-color":"var(--color-warning)","color":"var(--color-warning-content)"}},".chat-bubble-error":{"@layer daisyui.l1.l2":{"background-color":"var(--color-error)","color":"var(--color-error-content)"}},".chat-image":{"@layer daisyui.l1.l2.l3":{"grid-row":"span 2 / span 2","align-self":"flex-end"}},".chat-header":{"@layer daisyui.l1.l2.l3":{"grid-row-start":"1","display":"flex","gap":"calc(0.25rem * 1)","font-size":"0.6875rem"}},".chat-footer":{"@layer daisyui.l1.l2.l3":{"grid-row-start":"3","display":"flex","gap":"calc(0.25rem * 1)","font-size":"0.6875rem"}},".chat-start":{"@layer daisyui.l1.l2":{"place-items":"start","grid-template-columns":"auto 1fr",".chat-header":{"grid-column-start":"2"},".chat-footer":{"grid-column-start":"2"},".chat-image":{"grid-column-start":"1"},".chat-bubble":{"grid-column-start":"2","border-end-start-radius":"0","&:before":{"transform":"rotateY(0deg)","inset-inline-start":"-0.75rem"},"[dir=\"rtl\"] &:before":{"transform":"rotateY(180deg)"}}}},".chat-end":{"@layer daisyui.l1.l2":{"place-items":"end","grid-template-columns":"1fr auto",".chat-header":{"grid-column-start":"1"},".chat-footer":{"grid-column-start":"1"},".chat-image":{"grid-column-start":"2"},".chat-bubble":{"grid-column-start":"1","border-end-end-radius":"0","&:before":{"transform":"rotateY(180deg)","inset-inline-start":"100%"},"[dir=\"rtl\"] &:before":{"transform":"rotateY(0deg)"}}}}};