/*! 🌼 daisyUI 5.5.4 - MIT License */ @layer utilities{.skeleton{@layer daisyui.l1.l2.l3{&{border-radius:var(--radius-box);background-color:var(--color-base-300);will-change:background-position;background-image:linear-gradient(105deg,#0000 0% 40%,var(--color-base-100)50%,#0000 60% 100%);background-position-x:-50%;background-size:200%}@media (prefers-reduced-motion:reduce){&{transition-duration:15s}}@media (prefers-reduced-motion:no-preference){&{animation:1.8s ease-in-out infinite skeleton}}}}.skeleton-text{@layer daisyui.l1.l2{&{color:#0000;-webkit-background-clip:text;background-clip:text;background-image:linear-gradient(105deg,color-mix(in oklab,var(--color-base-content)20%,transparent)0% 40%,var(--color-base-content)50%,color-mix(in oklab,var(--color-base-content)20%,transparent)60% 100%)}}}@keyframes skeleton{0%{background-position:150%}to{background-position:-50%}}}