export default {".steps":{"@layer daisyui.l1.l2.l3":{"display":"inline-grid","grid-auto-flow":"column","overflow":"hidden","overflow-x":"auto","counter-reset":"step","grid-auto-columns":"1fr",".step":{"display":"grid","grid-template-columns":["repeat(1, minmax(0, 1fr))","auto"],"grid-template-rows":["repeat(2, minmax(0, 1fr))","40px 1fr"],"place-items":"center","text-align":"center","min-width":"4rem","--step-bg":"var(--color-base-300)","--step-fg":"var(--color-base-content)","&:before":{"top":"calc(0.25rem * 0)","grid-column-start":"1","grid-row-start":"1","height":"calc(0.25rem * 2)","width":"100%","border":"1px solid","color":"var(--step-bg)","background-color":"var(--step-bg)","content":"\"\"","margin-inline-start":"-100%"},"> .step-icon, &:not(:has(.step-icon)):after":{"--tw-content":"counter(step)","content":"var(--tw-content)","counter-increment":"step","z-index":1,"color":"var(--step-fg)","background-color":"var(--step-bg)","border":"1px solid var(--step-bg)","position":"relative","grid-column-start":"1","grid-row-start":"1","display":"grid","height":"calc(0.25rem * 8)","width":"calc(0.25rem * 8)","place-items":"center","place-self":"center","border-radius":"calc(infinity * 1px)"},"&:first-child:before":{"--tw-content":"none","content":"var(--tw-content)"},"&[data-content]:after":{"--tw-content":"attr(data-content)","content":"var(--tw-content)"}}},"@layer daisyui.l1.l2":{".step-neutral":{"+ .step-neutral:before, &:after, > .step-icon":{"--step-bg":"var(--color-neutral)","--step-fg":"var(--color-neutral-content)"}},".step-primary":{"+ .step-primary:before, &:after, > .step-icon":{"--step-bg":"var(--color-primary)","--step-fg":"var(--color-primary-content)"}},".step-secondary":{"+ .step-secondary:before, &:after, > .step-icon":{"--step-bg":"var(--color-secondary)","--step-fg":"var(--color-secondary-content)"}},".step-accent":{"+ .step-accent:before, &:after, > .step-icon":{"--step-bg":"var(--color-accent)","--step-fg":"var(--color-accent-content)"}},".step-info":{"+ .step-info:before, &:after, > .step-icon":{"--step-bg":"var(--color-info)","--step-fg":"var(--color-info-content)"}},".step-success":{"+ .step-success:before, &:after, > .step-icon":{"--step-bg":"var(--color-success)","--step-fg":"var(--color-success-content)"}},".step-warning":{"+ .step-warning:before, &:after, > .step-icon":{"--step-bg":"var(--color-warning)","--step-fg":"var(--color-warning-content)"}},".step-error":{"+ .step-error:before, &:after, > .step-icon":{"--step-bg":"var(--color-error)","--step-fg":"var(--color-error-content)"}}}},".steps-horizontal":{"@layer daisyui.l1.l2":{"grid-auto-columns":"1fr","display":"inline-grid","grid-auto-flow":"column","overflow":"hidden","overflow-x":"auto",".step":{"display":"grid","grid-template-columns":["repeat(1, minmax(0, 1fr))","auto"],"grid-template-rows":["repeat(2, minmax(0, 1fr))","40px 1fr"],"place-items":"center","text-align":"center","min-width":"4rem","&:before":{"height":"calc(0.25rem * 2)","width":"100%","translate":"0","margin-inline-start":"-100%"},"[dir=\"rtl\"] &:before":{"translate":"0"}}}},".steps-vertical":{"@layer daisyui.l1.l2":{"grid-auto-rows":"1fr","grid-auto-flow":"row",".step":{"display":"grid","grid-template-columns":["repeat(2, minmax(0, 1fr))","40px 1fr"],"grid-template-rows":["repeat(1, minmax(0, 1fr))","auto"],"gap":"0.5rem","min-height":"4rem","justify-items":"start","&:before":{"height":"100%","width":"calc(0.25rem * 2)","translate":"-50% -50%","margin-inline-start":"50%"},"[dir=\"rtl\"] &:before":{"translate":"50% -50%"}}}}};