export default {".dock":{"@layer daisyui.l1.l2.l3":{"position":"fixed","right":"calc(0.25rem * 0)","bottom":"calc(0.25rem * 0)","left":"calc(0.25rem * 0)","z-index":1,"display":"flex","width":"100%","flex-direction":"row","align-items":"center","justify-content":"space-around","background-color":"var(--color-base-100)","padding":"calc(0.25rem * 2)","color":"currentcolor","border-top":"0.5px solid color-mix(in oklab, var(--color-base-content) 5%, #0000)","height":["4rem","calc(4rem + env(safe-area-inset-bottom))"],"padding-bottom":"env(safe-area-inset-bottom)","> *":{"position":"relative","margin-bottom":"calc(0.25rem * 2)","display":"flex","height":"100%","max-width":"calc(0.25rem * 32)","flex-shrink":1,"flex-basis":"100%","cursor":"pointer","flex-direction":"column","align-items":"center","justify-content":"center","gap":"1px","border-radius":"var(--radius-box)","background-color":"transparent","transition":"opacity 0.2s ease-out","@media (hover: hover)":{"&:hover":{"opacity":"80%"}},"&[aria-disabled=\"true\"], &[disabled]":{"&, &:hover":{"pointer-events":"none","color":"color-mix(in oklab, var(--color-base-content) 10%, transparent)","opacity":"100%"}},".dock-label":{"font-size":"0.6875rem"},"&:after":{"content":"\"\"","position":"absolute","height":"calc(0.25rem * 1)","width":"calc(0.25rem * 6)","border-radius":"calc(infinity * 1px)","background-color":"transparent","bottom":"0.2rem","border-top":"3px solid transparent","transition":"background-color 0.1s ease-out, text-color 0.1s ease-out, width 0.1s ease-out"}}}},".dock-active":{"@layer daisyui.l1.l2":{"&:after":{"width":"calc(0.25rem * 10)","background-color":"currentcolor","color":"currentcolor"}}},".dock-xs":{"@layer daisyui.l1.l2":{"height":["3rem","calc(3rem + env(safe-area-inset-bottom))"],".dock-active":{"&:after":{"bottom":"-0.1rem"}},".dock-label":{"font-size":"0.625rem"}}},".dock-sm":{"@layer daisyui.l1.l2":{"height":["calc(0.25rem * 14)","3.5rem","calc(3.5rem + env(safe-area-inset-bottom))"],".dock-active":{"&:after":{"bottom":"-0.1rem"}},".dock-label":{"font-size":"0.625rem"}}},".dock-md":{"@layer daisyui.l1.l2":{"height":["4rem","calc(4rem + env(safe-area-inset-bottom))"],".dock-label":{"font-size":"0.6875rem"}}},".dock-lg":{"@layer daisyui.l1.l2":{"height":["4.5rem","calc(4.5rem + env(safe-area-inset-bottom))"],".dock-active":{"&:after":{"bottom":"0.4rem"}},".dock-label":{"font-size":"0.6875rem"}}},".dock-xl":{"@layer daisyui.l1.l2":{"height":["5rem","calc(5rem + env(safe-area-inset-bottom))"],".dock-active":{"&:after":{"bottom":"0.4rem"}},".dock-label":{"font-size":"0.75rem"}}}};