export default {".skeleton":{"@layer daisyui.l1.l2.l3":{"border-radius":"var(--radius-box)","background-color":"var(--color-base-300)","@media (prefers-reduced-motion: reduce)":{"transition-duration":"15s"},"will-change":"background-position","background-image":"linear-gradient( 105deg, #0000 0% 40%, var(--color-base-100) 50%, #0000 60% 100% )","background-size":"200% auto","background-position-x":"-50%","@media (prefers-reduced-motion: no-preference)":{"animation":"skeleton 1.8s ease-in-out infinite"}}},".skeleton-text":{"@layer daisyui.l1.l2":{"background-clip":"text","webkit-background-clip":"text","color":"transparent","background-image":"linear-gradient( 105deg, color-mix(in oklab, var(--color-base-content) 20%, transparent) 0% 40%, var(--color-base-content) 50%, color-mix(in oklab, var(--color-base-content) 20%, transparent) 60% 100% )"}},"@keyframes skeleton":{"0%":{"background-position":"150%"},"100%":{"background-position":"-50%"}}};