import progress from './object.js';
import { addPrefix } from '../../functions/addPrefix.js';

export default ({ addComponents, prefix = '' }) => {
  const prefixedprogress = addPrefix(progress, prefix);
  addComponents({ ...prefixedprogress });
};
