export default {".rating":{"@layer daisyui.l1.l2.l3":{"position":"relative","display":"inline-flex","vertical-align":"middle","& input":{"border":"none","appearance":"none"},":where(*)":{"height":"calc(0.25rem * 6)","width":"calc(0.25rem * 6)","border-radius":"0","background-color":"var(--color-base-content)","opacity":"20%","@media (prefers-reduced-motion: no-preference)":{"animation":"rating 0.25s ease-out"},"&:is(input)":{"cursor":"pointer"}},"& .rating-hidden":{"width":"calc(0.25rem * 2)","background-color":"transparent"},"input[type=\"radio\"]:checked":{"background-image":"none"},"*":{"&:checked, &[aria-checked=\"true\"], &[aria-current=\"true\"], &:has(~ *:checked, ~ *[aria-checked=\"true\"], ~ *[aria-current=\"true\"])":{"opacity":"100%"},"&:focus-visible":{"scale":"1.1","@media (prefers-reduced-motion: no-preference)":{"transition":"scale 0.2s ease-out"}}},"& *:active:focus":{"animation":"none","scale":"1.1"}},"@layer daisyui.l1.l2":{"&.rating-xs :where(*:not(.rating-hidden))":{"width":"calc(0.25rem * 4)","height":"calc(0.25rem * 4)"},"&.rating-sm :where(*:not(.rating-hidden))":{"width":"calc(0.25rem * 5)","height":"calc(0.25rem * 5)"},"&.rating-md :where(*:not(.rating-hidden))":{"width":"calc(0.25rem * 6)","height":"calc(0.25rem * 6)"},"&.rating-lg :where(*:not(.rating-hidden))":{"width":"calc(0.25rem * 7)","height":"calc(0.25rem * 7)"},"&.rating-xl :where(*:not(.rating-hidden))":{"width":"calc(0.25rem * 8)","height":"calc(0.25rem * 8)"}}},".rating-half":{"@layer daisyui.l1.l2":{"&.rating-xs *:not(.rating-hidden)":{"width":"calc(0.25rem * 2)"},"&.rating-sm *:not(.rating-hidden)":{"width":"calc(0.25rem * 2.5)"},"&.rating-md *:not(.rating-hidden)":{"width":"calc(0.25rem * 3)"},"&.rating-lg *:not(.rating-hidden)":{"width":".875rem"},"&.rating-xl *:not(.rating-hidden)":{"width":"calc(0.25rem * 4)"}}},"@keyframes rating":{"0%, 40%":{"scale":"1.1","filter":"brightness(1.05) contrast(1.05)"}}};