export default {".divider":{"@layer daisyui.l1.l2.l3":{"display":"flex","height":"calc(0.25rem * 4)","flex-direction":"row","align-items":"center","align-self":"stretch","white-space":"nowrap","margin":"var(--divider-m, 1rem 0)","--divider-color":"color-mix(in oklab, var(--color-base-content) 10%, transparent)","&:before, &:after":{"content":"\"\"","height":"calc(0.25rem * 0.5)","width":"100%","flex-grow":1,"background-color":"var(--divider-color)"},"@media print":{"&:before, &:after":{"border":"0.5px solid"}},"&:not(:empty)":{"gap":"calc(0.25rem * 4)"}}},".divider-horizontal":{"@layer daisyui.l1.l2":{"--divider-m":"0 1rem","&.divider":{"height":"auto","width":"calc(0.25rem * 4)","flex-direction":"column","&:before":{"height":"100%","width":"calc(0.25rem * 0.5)"},"&:after":{"height":"100%","width":"calc(0.25rem * 0.5)"}}}},".divider-vertical":{"@layer daisyui.l1.l2":{"--divider-m":"1rem 0","&.divider":{"height":"calc(0.25rem * 4)","width":"auto","flex-direction":"row","&:before":{"height":"calc(0.25rem * 0.5)","width":"100%"},"&:after":{"height":"calc(0.25rem * 0.5)","width":"100%"}}}},".divider-neutral":{"@layer daisyui.l1.l2":{"&:before, &:after":{"background-color":"var(--color-neutral)"}}},".divider-primary":{"@layer daisyui.l1.l2":{"&:before, &:after":{"background-color":"var(--color-primary)"}}},".divider-secondary":{"@layer daisyui.l1.l2":{"&:before, &:after":{"background-color":"var(--color-secondary)"}}},".divider-accent":{"@layer daisyui.l1.l2":{"&:before, &:after":{"background-color":"var(--color-accent)"}}},".divider-success":{"@layer daisyui.l1.l2":{"&:before, &:after":{"background-color":"var(--color-success)"}}},".divider-warning":{"@layer daisyui.l1.l2":{"&:before, &:after":{"background-color":"var(--color-warning)"}}},".divider-info":{"@layer daisyui.l1.l2":{"&:before, &:after":{"background-color":"var(--color-info)"}}},".divider-error":{"@layer daisyui.l1.l2":{"&:before, &:after":{"background-color":"var(--color-error)"}}},".divider-start:before":{"@layer daisyui.l1.l2":{"display":"none"}},".divider-end:after":{"@layer daisyui.l1.l2":{"display":"none"}}};