import hover3d from './object.js';
import { addPrefix } from '../../functions/addPrefix.js';

export default ({ addComponents, prefix = '' }) => {
  const prefixedhover3d = addPrefix(hover3d, prefix);
  addComponents({ ...prefixedhover3d });
};
