export default {".footer":{"@layer daisyui.l1.l2.l3":{"display":"grid","width":"100%","grid-auto-flow":"row","place-items":"start","column-gap":"calc(0.25rem * 4)","row-gap":"calc(0.25rem * 10)","font-size":"0.875rem","line-height":"1.25rem","& > *":{"display":"grid","place-items":"start","gap":"calc(0.25rem * 2)"},"&.footer-center":{"grid-auto-flow":"column dense","place-items":"center","text-align":"center","& > *":{"place-items":"center"}}}},".footer-title":{"@layer daisyui.l1.l2.l3":{"margin-bottom":"calc(0.25rem * 2)","text-transform":"uppercase","opacity":"60%","font-weight":600}},".footer-horizontal":{"@layer daisyui.l1.l2":{"grid-auto-flow":"column","&.footer-center":{"grid-auto-flow":"row dense"}}},".footer-vertical":{"@layer daisyui.l1.l2":{"grid-auto-flow":"row","&.footer-center":{"grid-auto-flow":"column dense"}}}};