export default {".radio":{"@layer daisyui.l1.l2.l3":{"position":"relative","display":"inline-block","flex-shrink":0,"cursor":"pointer","appearance":"none","border-radius":"calc(infinity * 1px)","padding":"calc(0.25rem * 1)","vertical-align":"middle","border":"var(--border) solid var(--input-color, color-mix(in srgb, currentColor 20%, #0000))","box-shadow":"0 1px oklch(0% 0 0 / calc(var(--depth) * 0.1)) inset","--size":"calc(var(--size-selector, 0.25rem) * 6)","width":"var(--size)","height":"var(--size)","color":"var(--input-color, currentColor)","&:before":{"display":"block","width":"100%","height":"100%","border-radius":"calc(infinity * 1px)","--tw-content":"\"\"","content":"var(--tw-content)","background-size":"auto, calc(var(--noise) * 100%)","background-image":"none, var(--fx-noise)"},"&:focus-visible":{"outline":"2px solid currentColor"},"&:checked, &[aria-checked=\"true\"]":{"border-color":"currentcolor","background-color":"var(--color-base-100)","@media (prefers-reduced-motion: no-preference)":{"animation":"radio 0.2s ease-out"},"&:before":{"background-color":"currentcolor","box-shadow":"0 -1px oklch(0% 0 0 / calc(var(--depth) * 0.1)) inset, 0 8px 0 -4px oklch(100% 0 0 / calc(var(--depth) * 0.1)) inset, 0 1px oklch(0% 0 0 / calc(var(--depth) * 0.1))"},"@media (forced-colors: active)":{"&:before":{"outline-style":"var(--tw-outline-style)","outline-width":"1px","outline-offset":"calc(1px * -1)"}},"@media print":{"&:before":{"outline":"0.25rem solid","outline-offset":"-1rem"}}}}},".radio-primary":{"@layer daisyui.l1.l2":{"--input-color":"var(--color-primary)"}},".radio-secondary":{"@layer daisyui.l1.l2":{"--input-color":"var(--color-secondary)"}},".radio-accent":{"@layer daisyui.l1.l2":{"--input-color":"var(--color-accent)"}},".radio-neutral":{"@layer daisyui.l1.l2":{"--input-color":"var(--color-neutral)"}},".radio-info":{"@layer daisyui.l1.l2":{"--input-color":"var(--color-info)"}},".radio-success":{"@layer daisyui.l1.l2":{"--input-color":"var(--color-success)"}},".radio-warning":{"@layer daisyui.l1.l2":{"--input-color":"var(--color-warning)"}},".radio-error":{"@layer daisyui.l1.l2":{"--input-color":"var(--color-error)"}},".radio:disabled":{"@layer daisyui.l1.l2":{"cursor":"not-allowed","opacity":"20%"}},".radio-xs":{"@layer daisyui.l1.l2":{"padding":"0.125rem","&:is([type=\"radio\"])":{"--size":"calc(var(--size-selector, 0.25rem) * 4)"}}},".radio-sm":{"@layer daisyui.l1.l2":{"padding":"0.1875rem","&:is([type=\"radio\"])":{"--size":"calc(var(--size-selector, 0.25rem) * 5)"}}},".radio-md":{"@layer daisyui.l1.l2":{"padding":"0.25rem","&:is([type=\"radio\"])":{"--size":"calc(var(--size-selector, 0.25rem) * 6)"}}},".radio-lg":{"@layer daisyui.l1.l2":{"padding":"0.3125rem","&:is([type=\"radio\"])":{"--size":"calc(var(--size-selector, 0.25rem) * 7)"}}},".radio-xl":{"@layer daisyui.l1.l2":{"padding":"0.375rem","&:is([type=\"radio\"])":{"--size":"calc(var(--size-selector, 0.25rem) * 8)"}}},"@keyframes radio":{"0%":{"padding":"5px"},"50%":{"padding":"3px"}}};