export default {".carousel":{"@layer daisyui.l1.l2.l3":{"display":"inline-flex","overflow-x":"scroll","scroll-snap-type":"x mandatory","scrollbar-width":"none","@media (prefers-reduced-motion: no-preference)":{"scroll-behavior":"smooth"},"&::-webkit-scrollbar":{"display":"none"}}},".carousel-vertical":{"@layer daisyui.l1.l2":{"flex-direction":"column","overflow-y":"scroll","scroll-snap-type":"y mandatory"}},".carousel-horizontal":{"@layer daisyui.l1.l2":{"flex-direction":"row","overflow-x":"scroll","scroll-snap-type":"x mandatory"}},".carousel-item":{"@layer daisyui.l1.l2.l3":{"box-sizing":"content-box","display":"flex","flex":"none","scroll-snap-align":"start"}},".carousel-start":{"@layer daisyui.l1.l2":{".carousel-item":{"scroll-snap-align":"start"}}},".carousel-center":{"@layer daisyui.l1.l2":{".carousel-item":{"scroll-snap-align":"center"}}},".carousel-end":{"@layer daisyui.l1.l2":{".carousel-item":{"scroll-snap-align":"end"}}}};