import indicator from './object.js';
import { addPrefix } from '../../functions/addPrefix.js';

export default ({ addComponents, prefix = '' }) => {
  const prefixedindicator = addPrefix(indicator, prefix);
  addComponents({ ...prefixedindicator });
};
